==> netgen_occt-0.0.1.dev0-py3-none-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_occt-0.0.1.dev0.data/data/lib/cmake/opencascade/OpenCASCADEModelingAlgorithmsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKGeomAlgo" for configuration "Release"
set_property(TARGET TKGeomAlgo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKGeomAlgo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKGeomAlgo.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKGeomAlgo.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKGeomAlgo )
list(APPEND _cmake_import_check_files_for_TKGeomAlgo "${_IMPORT_PREFIX}/./libTKGeomAlgo.so.7.8.2" )

# Import target "TKTopAlgo" for configuration "Release"
set_property(TARGET TKTopAlgo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKTopAlgo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKTopAlgo.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKTopAlgo.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKTopAlgo )
list(APPEND _cmake_import_check_files_for_TKTopAlgo "${_IMPORT_PREFIX}/./libTKTopAlgo.so.7.8.2" )

# Import target "TKPrim" for configuration "Release"
set_property(TARGET TKPrim APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKPrim PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKPrim.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKPrim.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKPrim )
list(APPEND _cmake_import_check_files_for_TKPrim "${_IMPORT_PREFIX}/./libTKPrim.so.7.8.2" )

# Import target "TKBO" for configuration "Release"
set_property(TARGET TKBO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBO PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKBO.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBO.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBO )
list(APPEND _cmake_import_check_files_for_TKBO "${_IMPORT_PREFIX}/./libTKBO.so.7.8.2" )

# Import target "TKShHealing" for configuration "Release"
set_property(TARGET TKShHealing APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKShHealing PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKShHealing.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKShHealing.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKShHealing )
list(APPEND _cmake_import_check_files_for_TKShHealing "${_IMPORT_PREFIX}/./libTKShHealing.so.7.8.2" )

# Import target "TKBool" for configuration "Release"
set_property(TARGET TKBool APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBool PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKBool.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBool.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBool )
list(APPEND _cmake_import_check_files_for_TKBool "${_IMPORT_PREFIX}/./libTKBool.so.7.8.2" )

# Import target "TKHLR" for configuration "Release"
set_property(TARGET TKHLR APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKHLR PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKHLR.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKHLR.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKHLR )
list(APPEND _cmake_import_check_files_for_TKHLR "${_IMPORT_PREFIX}/./libTKHLR.so.7.8.2" )

# Import target "TKFillet" for configuration "Release"
set_property(TARGET TKFillet APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKFillet PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKFillet.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKFillet.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKFillet )
list(APPEND _cmake_import_check_files_for_TKFillet "${_IMPORT_PREFIX}/./libTKFillet.so.7.8.2" )

# Import target "TKOffset" for configuration "Release"
set_property(TARGET TKOffset APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKOffset PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKOffset.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKOffset.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKOffset )
list(APPEND _cmake_import_check_files_for_TKOffset "${_IMPORT_PREFIX}/./libTKOffset.so.7.8.2" )

# Import target "TKFeat" for configuration "Release"
set_property(TARGET TKFeat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKFeat PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKFeat.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKFeat.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKFeat )
list(APPEND _cmake_import_check_files_for_TKFeat "${_IMPORT_PREFIX}/./libTKFeat.so.7.8.2" )

# Import target "TKMesh" for configuration "Release"
set_property(TARGET TKMesh APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKMesh PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKMesh.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKMesh.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKMesh )
list(APPEND _cmake_import_check_files_for_TKMesh "${_IMPORT_PREFIX}/./libTKMesh.so.7.8.2" )

# Import target "TKXMesh" for configuration "Release"
set_property(TARGET TKXMesh APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXMesh PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKXMesh.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXMesh.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXMesh )
list(APPEND _cmake_import_check_files_for_TKXMesh "${_IMPORT_PREFIX}/./libTKXMesh.so.7.8.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> netgen_occt-0.0.5-py3-none-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_occt-0.0.5.data/data/lib/cmake/opencascade/OpenCASCADEModelingAlgorithmsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKGeomAlgo" for configuration "Release"
set_property(TARGET TKGeomAlgo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKGeomAlgo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKGeomAlgo.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKGeomAlgo.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKGeomAlgo )
list(APPEND _cmake_import_check_files_for_TKGeomAlgo "${_IMPORT_PREFIX}/lib/libTKGeomAlgo.so.7.8.2" )

# Import target "TKTopAlgo" for configuration "Release"
set_property(TARGET TKTopAlgo APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKTopAlgo PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKTopAlgo.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKTopAlgo.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKTopAlgo )
list(APPEND _cmake_import_check_files_for_TKTopAlgo "${_IMPORT_PREFIX}/lib/libTKTopAlgo.so.7.8.2" )

# Import target "TKPrim" for configuration "Release"
set_property(TARGET TKPrim APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKPrim PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKPrim.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKPrim.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKPrim )
list(APPEND _cmake_import_check_files_for_TKPrim "${_IMPORT_PREFIX}/lib/libTKPrim.so.7.8.2" )

# Import target "TKBO" for configuration "Release"
set_property(TARGET TKBO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBO PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKBO.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBO.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBO )
list(APPEND _cmake_import_check_files_for_TKBO "${_IMPORT_PREFIX}/lib/libTKBO.so.7.8.2" )

# Import target "TKShHealing" for configuration "Release"
set_property(TARGET TKShHealing APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKShHealing PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKShHealing.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKShHealing.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKShHealing )
list(APPEND _cmake_import_check_files_for_TKShHealing "${_IMPORT_PREFIX}/lib/libTKShHealing.so.7.8.2" )

# Import target "TKBool" for configuration "Release"
set_property(TARGET TKBool APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBool PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKBool.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBool.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBool )
list(APPEND _cmake_import_check_files_for_TKBool "${_IMPORT_PREFIX}/lib/libTKBool.so.7.8.2" )

# Import target "TKHLR" for configuration "Release"
set_property(TARGET TKHLR APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKHLR PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKHLR.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKHLR.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKHLR )
list(APPEND _cmake_import_check_files_for_TKHLR "${_IMPORT_PREFIX}/lib/libTKHLR.so.7.8.2" )

# Import target "TKFillet" for configuration "Release"
set_property(TARGET TKFillet APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKFillet PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKFillet.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKFillet.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKFillet )
list(APPEND _cmake_import_check_files_for_TKFillet "${_IMPORT_PREFIX}/lib/libTKFillet.so.7.8.2" )

# Import target "TKOffset" for configuration "Release"
set_property(TARGET TKOffset APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKOffset PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKOffset.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKOffset.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKOffset )
list(APPEND _cmake_import_check_files_for_TKOffset "${_IMPORT_PREFIX}/lib/libTKOffset.so.7.8.2" )

# Import target "TKFeat" for configuration "Release"
set_property(TARGET TKFeat APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKFeat PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKFeat.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKFeat.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKFeat )
list(APPEND _cmake_import_check_files_for_TKFeat "${_IMPORT_PREFIX}/lib/libTKFeat.so.7.8.2" )

# Import target "TKMesh" for configuration "Release"
set_property(TARGET TKMesh APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKMesh PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKMesh.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKMesh.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKMesh )
list(APPEND _cmake_import_check_files_for_TKMesh "${_IMPORT_PREFIX}/lib/libTKMesh.so.7.8.2" )

# Import target "TKXMesh" for configuration "Release"
set_property(TARGET TKXMesh APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXMesh PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKXMesh.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXMesh.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXMesh )
list(APPEND _cmake_import_check_files_for_TKXMesh "${_IMPORT_PREFIX}/lib/libTKXMesh.so.7.8.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
